"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBindInfo = exports.getAvailableFunction = exports.getLightAndLinkage = exports.getSceneList = exports.getHomeId = void 0;
exports.checkGroupCreatable = checkGroupCreatable;
const ray_1 = require("@ray-js/ray");
let _homeId = null;
// let _homeInfo = null;
ray_1.home.getCurrentHomeInfo({
    success: res => {
        // _homeInfo = res;
        _homeId = res.homeId;
    }
});
const getHomeId = () => {
    if (_homeId) {
        return Promise.resolve(_homeId);
    }
    return new Promise((resolve, reject) => {
        ray_1.home.getCurrentHomeInfo({
            success: res => {
                // _homeInfo = res;
                _homeId = res.homeId;
                resolve(_homeId);
            },
            fail: error => {
                reject(error);
            }
        });
    });
};
exports.getHomeId = getHomeId;
const request = (api, version, params) => {
    return new Promise((resolve, reject) => __awaiter(void 0, void 0, void 0, function* () {
        console.log('request api:', api);
        console.log('request version params', version);
        console.log('request params', params);
        (0, ray_1.apiRequestByAtop)({
            api,
            version,
            postData: params,
            extData: {
                gid: yield (0, exports.getHomeId)(),
            },
            success: response => {
                console.log('%c request success', 'color: green', api, response);
                resolve({
                    result: response,
                });
            },
            fail: error => {
                reject(error);
                console.warn('%c request fail', 'color: yellow', api, error);
            },
        });
    }));
};
const getSceneList = (params) => __awaiter(void 0, void 0, void 0, function* () {
    const url = 'm.light.rc.bindable.rule.list';
    const version = '1.0';
    return request(url, version, params);
});
exports.getSceneList = getSceneList;
const getLightAndLinkage = (params) => __awaiter(void 0, void 0, void 0, function* () {
    const { result: list } = yield (0, exports.getSceneList)(Object.assign({ bindType: 1 }, params));
    const lightList = list.filter(item => item.ruleType === 1);
    const dimmingList = list.filter(item => item.ruleType === 2);
    const linkageList = list.filter(item => item.ruleType === 3);
    const result = {
        lightList,
        linkageList,
        dimmingList,
    };
    return result;
});
exports.getLightAndLinkage = getLightAndLinkage;
/**
 * 获取指定 dp 点可用的功能列表
 * @param params masterDevId 主控设备ID
 * @param params masterDpIds 主控设备的 DPID, 多个以英文逗号隔开
 * @returns
 */
const getAvailableFunction = (params) => {
    const api = 'm.light.rc.btn.available.function.list';
    const version = '1.0';
    return request(api, version, params);
};
exports.getAvailableFunction = getAvailableFunction;
/**
 * 获取绑定信息
 * @param params masterDevId 主控设备ID
 * @param params masterDpIds 主控设备的 DPID, 多个以英文逗号隔开
 * @returns
 */
const getBindInfo = (params) => {
    const api = 'm.light.rc.device.bind.query';
    const version = '1.0';
    return request(api, version, params);
};
exports.getBindInfo = getBindInfo;
/**
 * 查询主控设备是否可以创建群组（继电器）
 * @param ids 主控设备的 DPID, 多个以英文逗号隔开
 * @returns
 */
function checkGroupCreatable(ids, devId) {
    const api = 'm.light.rc.dp.group.creatable.check';
    const version = '1.0';
    const { deviceId } = (0, ray_1.getLaunchOptionsSync)().query;
    return request(api, version, {
        masterDevId: devId || deviceId,
        masterDpIds: ids,
    });
}
