import { GETAvailableFunctionParams } from './api';
export * from './api';
export * from './consts';
import { BIND_TYPE } from './consts';
interface DeviceSelectParams {
    /**
     * 绑定类型
     * @type {string}
     * @description 1: 场景控制 2: 场景调光 3: 灯光控制 4: 窗帘控制 5: 空调控制 6: 电视控制 7: 非智能灯 8: 音响控制 9: 语音中控
     * 10: 分布式蓝牙灯光场景(单状态) 11: 蓝牙SoC方案的房间调光 12: 蓝牙SoC方案的灯具控制 13: 蓝牙SoC方案的窗帘 18: 分布式蓝牙灯光场景-双状态 19: 蓝牙SoC方案的灯具控制-取反 23: 蓝牙虚拟设备
     */
    type: typeof BIND_TYPE[keyof typeof BIND_TYPE];
    /**
     * 按键 ID
     * @type {string}
     * @description 当前按钮在当前设备的索引(button_install_x)
     */
    buttonId: string;
    /**
     * 当前按钮对应的dpId
     */
    dpId: number;
    /**
     * 当前按钮对应的 dp code
     */
    code: string;
    /**
     * 当前家庭ID, ty.home.getCurrentHomeInfo
     */
    homeId?: number;
    /**
     * 对内容进行预设，现只支持 actions 字段。
     * 示例：
     * {
     *  actions: {
     *   1: {icon: require('path'), title: '灯光1', desc: '描述1'},
     *   2: {icon: require('path'), title: '灯光2', desc: '描述2'},
     *  [bindType]: {icon: require('path'), title: '灯光3', desc: '描述3'},
     * }
     */
    preset?: Record<string, any>;
}
/**
 * 打开设备选择或调光选择
 */
export declare function openDeviceOrDimmingSelect(params: DeviceSelectParams): Promise<void>;
type SceneSelectParams = Omit<DeviceSelectParams, 'type'>;
/**
 * 打开场景选择（一键执行）
 */
export declare function openSceneSelect(params: SceneSelectParams): Promise<void>;
type VirtualDeviceBindParams = Omit<DeviceSelectParams, 'type'> & {
    /**
     * 当前按钮对应的群组执行dpId, 查看绑定详情时不需要传
     */
    groupExecuteDpId?: number;
    /**
     * 绑定规则(绑定详情时传)
     */
    bindRule?: any;
};
/**
 * 绑定或查看虚拟设备详情
 */
export declare function openVirtualDeviceBind(params: VirtualDeviceBindParams): Promise<void>;
type BindDetailParams = Omit<DeviceSelectParams, 'type'> & {
    /**
   * 绑定规则(绑定详情时传)
   */
    bindRule?: any;
};
/**
 * 打开绑定详情(除虚拟设备外的其他情况)
 */
export declare function openBindDetail(params: BindDetailParams): Promise<void>;
/**
 * 获取可用功能列表，与本地配置合并
 * @param params
 * @returns
 */
export declare function getAvailableFunctionList(params: GETAvailableFunctionParams): Promise<unknown>;
interface RelayConfigParams {
    /**
     * 继电器类型
     * @type {string}
     * @description 1: 单路 2: 双路 3: 三路 4: 四路
     */
    homeId?: number | string;
}
/**
 * 打开继电器配置页面
 * @param params RelayConfigParams 跳转参数
 */
export declare function openRelayConfig(params?: RelayConfigParams): Promise<void>;
type SleepModeConfigParams = RelayConfigParams;
/**
 * 打开睡眠模式配置页面
 * @param params SleepModeConfigParams 跳转参数
 */
export declare function openSleepModeConfig(params?: SleepModeConfigParams): Promise<void>;
